==> thunderbird_66.0~b1.orig.tar.xz: thunderbird-66.0/browser/components/newtab/prerendered/locales/de/activity-stream-strings.js <==
// Note - this is a generated de file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Neuer Tab",
  "header_top_sites": "Wichtige Seiten",
  "header_highlights": "Überblick",
  "header_recommended_by": "Empfohlen von {provider}",
  "context_menu_button_sr": "Kontextmenü für {title} öffnen",
  "section_context_menu_button_sr": "Kontextmenü des Abschnitts öffnen",
  "type_label_visited": "Besucht",
  "type_label_bookmarked": "Lesezeichen",
  "type_label_recommended": "Beliebt",
  "type_label_pocket": "Bei Pocket gespeichert",
  "type_label_downloaded": "Heruntergeladen",
  "menu_action_bookmark": "Lesezeichen",
  "menu_action_remove_bookmark": "Lesezeichen entfernen",
  "menu_action_open_new_window": "In neuem Fenster öffnen",
  "menu_action_open_private_window": "In neuem privaten Fenster öffnen",
  "menu_action_dismiss": "Entfernen",
  "menu_action_delete": "Aus Chronik löschen",
  "menu_action_pin": "Anheften",
  "menu_action_unpin": "Ablösen",
  "confirm_history_delete_p1": "Soll wirklich jede Instanz dieser Seite aus Ihrer Chronik gelöscht werden?",
  "confirm_history_delete_notice_p2": "Diese Aktion kann nicht rückgängig gemacht werden.",
  "menu_action_save_to_pocket": "Bei Pocket speichern",
  "menu_action_delete_pocket": "Aus Pocket löschen",
  "menu_action_archive_pocket": "In Pocket archivieren",
  "menu_action_show_file_mac_os": "Im Finder anzeigen",
  "menu_action_show_file_windows": "Beinhaltenden Ordner öffnen",
  "menu_action_show_file_linux": "Ziel-Ordner öffnen",
  "menu_action_show_file_default": "Datei anzeigen",
  "menu_action_open_file": "Datei öffnen",
  "menu_action_copy_download_link": "Download-Link kopieren",
  "menu_action_go_to_download_page": "Zur Download-Seite gehen",
  "menu_action_remove_download": "Aus Chronik entfernen",
  "search_button": "Suchen",
  "search_header": "{search_engine_name}-Suche",
  "search_web_placeholder": "Das Web durchsuchen",
  "section_disclaimer_topstories": "Die interessanten Geschichten im Internet, ausgewählt nach Ihrem Geschmack. Von Pocket, jetzt Teil von Mozilla.",
  "section_disclaimer_topstories_linktext": "Erfahren Sie, wie es funktioniert.",
  "section_disclaimer_topstories_buttontext": "Ok, verstanden",
  "prefs_home_header": "Inhalte des Firefox-Startbildschirms",
  "prefs_home_description": "Wählen Sie, welche Inhalte auf Ihrem Firefox-Startbildschirm angezeigt werden sollen.",
  "prefs_content_discovery_header": "Firefox Home",
  "prefs_content_discovery_description": "Content Discovery in Firefox Home allows you to discover high-quality, relevant articles from across the web.",
  "prefs_content_discovery_button": "Turn Off Content Discovery",
  "prefs_section_rows_option": "{num} Zeile;{num} Zeilen",
  "prefs_search_header": "Internetsuche",
  "prefs_topsites_description": "Die von die Ihnen am meisten besuchten Websites",
  "prefs_topstories_description2": "Tolle Inhalte aus dem ganzen Internet, für Sie personalisiert",
  "prefs_topstories_options_sponsored_label": "Gesponserte Geschichten",
  "prefs_topstories_sponsored_learn_more": "Weitere Informationen",
  "prefs_highlights_description": "Eine Auswahl von Websites, die Sie gespeichert oder besucht haben",
  "prefs_highlights_options_visited_label": "Besuchte Seiten",
  "prefs_highlights_options_download_label": "Neueste Downloads",
  "prefs_highlights_options_pocket_label": "Bei Pocket gespeicherte Seiten",
  "prefs_snippets_description": "Neuigkeiten von Mozilla und Firefox",
  "settings_pane_button_label": "Einstellungen für neue Tabs anpassen",
  "settings_pane_topsites_header": "Wichtige Seiten",
  "settings_pane_highlights_header": "Überblick",
  "settings_pane_highlights_options_bookmarks": "Lesezeichen",
  "settings_pane_snippets_header": "Kurzinformationen",
  "edit_topsites_button_text": "Bearbeiten",
  "edit_topsites_edit_button": "Diese Website bearbeiten",
  "topsites_form_add_header": "Neue wichtige Seite",
  "topsites_form_edit_header": "Wichtige Seite bearbeiten",
  "topsites_form_title_label": "Titel",
  "topsites_form_title_placeholder": "Name eingeben",
  "topsites_form_url_label": "Adresse",
  "topsites_form_image_url_label": "Adresse von benutzerdefinierter Grafik",
  "topsites_form_url_placeholder": "Eine Adresse eingeben oder einfügen",
  "topsites_form_use_image_link": "Eine benutzerdefinierte Grafik verwenden…",
  "topsites_form_preview_button": "Vorschau",
  "topsites_form_add_button": "Hinzufügen",
  "topsites_form_save_button": "Speichern",
  "topsites_form_cancel_button": "Abbrechen",
  "topsites_form_url_validation": "Gültige Adresse erforderlich",
  "topsites_form_image_validation": "Grafik konnte nicht geladen werden. Verwenden Sie eine andere Adresse.",
  "pocket_read_more": "Beliebte Themen:",
  "pocket_read_even_more": "Weitere Nachrichten ansehen",
  "pocket_more_reccommendations": "Mehr Empfehlungen",
  "pocket_how_it_works": "Wie es funktioniert",
  "pocket_cta_button": "Pocket holen",
  "pocket_cta_text": "Speichern Sie Ihre Lieblingstexte in Pocket und gewinnen Sie gedankenreiche Einblicke durch faszinierende Texte.",
  "highlights_empty_state": "Surfen Sie los und wir zeigen Ihnen hier einige der interessanten Artikel, Videos und anderen Seiten, die Sie kürzlich besucht oder als Lesezeichen gespeichert haben.",
  "topstories_empty_state": "Jetzt kennen Sie die Neuigkeiten. Schauen Sie später wieder vorbei, um neue Informationen von {provider} zu erhalten. Können Sie nicht warten? Wählen Sie ein beliebtes Thema und lesen Sie weitere interessante Geschichten aus dem Internet.",
  "manual_migration_explanation2": "Probieren Sie Firefox aus und importieren Sie die Lesezeichen, Chronik und Passwörter eines anderen Browsers.",
  "manual_migration_cancel_button": "Nein, danke",
  "manual_migration_import_button": "Jetzt importieren",
  "error_fallback_default_info": "Beim Laden dieses Inhalts ist ein Fehler aufgetreten.",
  "error_fallback_default_refresh_suggestion": "Aktualisieren Sie die Seite, um es erneut zu versuchen.",
  "section_menu_action_remove_section": "Abschnitt entfernen",
  "section_menu_action_collapse_section": "Abschnitt einklappen",
  "section_menu_action_expand_section": "Abschnitt ausklappen",
  "section_menu_action_manage_section": "Abschnitt verwalten",
  "section_menu_action_manage_webext": "Erweiterung verwalten",
  "section_menu_action_add_topsite": "Wichtige Seite hinzufügen",
  "section_menu_action_add_search_engine": "Suchmaschine hinzufügen",
  "section_menu_action_move_up": "Nach oben schieben",
  "section_menu_action_move_down": "Nach unten schieben",
  "section_menu_action_privacy_notice": "Datenschutzhinweis",
  "firstrun_title": "Firefox für unterwegs",
  "firstrun_content": "Nehmen Sie Ihre Lesezeichen, Chronik, Passwörter und andere Einstellungen auf allen Geräten mit.",
  "firstrun_learn_more_link": "Jetzt mehr über Firefox-Konten erfahren",
  "firstrun_form_header": "E-Mail-Adresse eingeben",
  "firstrun_form_sub_header": "um sich bei Firefox Sync anzumelden.",
  "firstrun_email_input_placeholder": "E-Mail",
  "firstrun_invalid_input": "Gültige E-Mail-Adresse erforderlich",
  "firstrun_extra_legal_links": "Indem Sie fortfahren, stimmen Sie den {terms} und dem {privacy} zu.",
  "firstrun_terms_of_service": "Nutzungsbedingungen",
  "firstrun_privacy_notice": "Datenschutzhinweis",
  "firstrun_continue_to_login": "Weiter",
  "firstrun_skip_login": "Diesen Schritt überspringen",
  "context_menu_title": "Menü öffnen"
};

==> thunderbird_68.10.0.orig.tar.xz: thunderbird-68.10.0/browser/components/newtab/prerendered/locales/de/activity-stream-strings.js <==
// Note - this is a generated de file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Neuer Tab",
  "header_top_sites": "Wichtige Seiten",
  "header_highlights": "Überblick",
  "header_recommended_by": "Empfohlen von {provider}",
  "context_menu_button_sr": "Kontextmenü für {title} öffnen",
  "section_context_menu_button_sr": "Kontextmenü des Abschnitts öffnen",
  "type_label_visited": "Besucht",
  "type_label_bookmarked": "Lesezeichen",
  "type_label_recommended": "Beliebt",
  "type_label_pocket": "Bei Pocket gespeichert",
  "type_label_downloaded": "Heruntergeladen",
  "menu_action_bookmark": "Lesezeichen",
  "menu_action_remove_bookmark": "Lesezeichen entfernen",
  "menu_action_open_new_window": "In neuem Fenster öffnen",
  "menu_action_open_private_window": "In neuem privaten Fenster öffnen",
  "menu_action_dismiss": "Entfernen",
  "menu_action_delete": "Aus Chronik löschen",
  "menu_action_pin": "Anheften",
  "menu_action_unpin": "Ablösen",
  "confirm_history_delete_p1": "Soll wirklich jede Instanz dieser Seite aus Ihrer Chronik gelöscht werden?",
  "confirm_history_delete_notice_p2": "Diese Aktion kann nicht rückgängig gemacht werden.",
  "menu_action_save_to_pocket": "Bei Pocket speichern",
  "menu_action_delete_pocket": "Aus Pocket löschen",
  "menu_action_archive_pocket": "In Pocket archivieren",
  "menu_action_show_file_mac_os": "Im Finder anzeigen",
  "menu_action_show_file_windows": "Beinhaltenden Ordner öffnen",
  "menu_action_show_file_linux": "Ziel-Ordner öffnen",
  "menu_action_show_file_default": "Datei anzeigen",
  "menu_action_open_file": "Datei öffnen",
  "menu_action_copy_download_link": "Download-Link kopieren",
  "menu_action_go_to_download_page": "Zur Download-Seite gehen",
  "menu_action_remove_download": "Aus Chronik entfernen",
  "search_button": "Suchen",
  "search_header": "{search_engine_name}-Suche",
  "search_web_placeholder": "Das Web durchsuchen",
  "section_disclaimer_topstories": "Die interessanten Geschichten im Internet, ausgewählt nach Ihrem Geschmack. Von Pocket, jetzt Teil von Mozilla.",
  "section_disclaimer_topstories_linktext": "Erfahren Sie, wie es funktioniert.",
  "section_disclaimer_topstories_buttontext": "Ok, verstanden",
  "prefs_home_header": "Inhalte des Firefox-Startbildschirms",
  "prefs_home_description": "Wählen Sie, welche Inhalte auf Ihrem Firefox-Startbildschirm angezeigt werden sollen.",
  "prefs_content_discovery_description": "\"Neues aus dem Netz\" macht auf gute Inhalte im Internet aufmerksam.",
  "prefs_section_rows_option": "{num} Zeile;{num} Zeilen",
  "prefs_search_header": "Internetsuche",
  "prefs_topsites_description": "Die von die Ihnen am meisten besuchten Websites",
  "prefs_topstories_description2": "Tolle Inhalte aus dem ganzen Internet, für Sie personalisiert",
  "prefs_topstories_options_sponsored_label": "Gesponserte Inhalte",
  "prefs_topstories_sponsored_learn_more": "Weitere Informationen",
  "prefs_highlights_description": "Eine Auswahl von Websites, die Sie gespeichert oder besucht haben",
  "prefs_highlights_options_visited_label": "Besuchte Seiten",
  "prefs_highlights_options_download_label": "Neueste Downloads",
  "prefs_highlights_options_pocket_label": "Bei Pocket gespeicherte Seiten",
  "prefs_snippets_description": "Neuigkeiten von Mozilla und Firefox",
  "settings_pane_button_label": "Einstellungen für neue Tabs anpassen",
  "settings_pane_topsites_header": "Wichtige Seiten",
  "settings_pane_highlights_header": "Überblick",
  "settings_pane_highlights_options_bookmarks": "Lesezeichen",
  "settings_pane_snippets_header": "Kurzinformationen",
  "edit_topsites_button_text": "Bearbeiten",
  "edit_topsites_edit_button": "Diese Website bearbeiten",
  "topsites_form_add_header": "Neue wichtige Seite",
  "topsites_form_edit_header": "Wichtige Seite bearbeiten",
  "topsites_form_title_label": "Titel",
  "topsites_form_title_placeholder": "Name eingeben",
  "topsites_form_url_label": "Adresse",
  "topsites_form_image_url_label": "Adresse von benutzerdefinierter Grafik",
  "topsites_form_url_placeholder": "Eine Adresse eingeben oder einfügen",
  "topsites_form_use_image_link": "Eine benutzerdefinierte Grafik verwenden…",
  "topsites_form_preview_button": "Vorschau",
  "topsites_form_add_button": "Hinzufügen",
  "topsites_form_save_button": "Speichern",
  "topsites_form_cancel_button": "Abbrechen",
  "topsites_form_url_validation": "Gültige Adresse erforderlich",
  "topsites_form_image_validation": "Grafik konnte nicht geladen werden. Verwenden Sie eine andere Adresse.",
  "pocket_read_more": "Beliebte Themen:",
  "pocket_read_even_more": "Weitere Nachrichten ansehen",
  "pocket_more_reccommendations": "Mehr Empfehlungen",
  "pocket_how_it_works": "Wie es funktioniert",
  "pocket_cta_button": "Pocket holen",
  "pocket_cta_text": "Speichern Sie Ihre Lieblingstexte in Pocket und gewinnen Sie gedankenreiche Einblicke durch faszinierende Texte.",
  "highlights_empty_state": "Surfen Sie los und wir zeigen Ihnen hier einige der interessanten Artikel, Videos und anderen Seiten, die Sie kürzlich besucht oder als Lesezeichen gespeichert haben.",
  "topstories_empty_state": "Jetzt kennen Sie die Neuigkeiten. Schauen Sie später wieder vorbei, um neue Informationen von {provider} zu erhalten. Können Sie nicht warten? Wählen Sie ein beliebtes Thema und lesen Sie weitere interessante Geschichten aus dem Internet.",
  "error_fallback_default_info": "Beim Laden dieses Inhalts ist ein Fehler aufgetreten.",
  "error_fallback_default_refresh_suggestion": "Aktualisieren Sie die Seite, um es erneut zu versuchen.",
  "section_menu_action_remove_section": "Abschnitt entfernen",
  "section_menu_action_collapse_section": "Abschnitt einklappen",
  "section_menu_action_expand_section": "Abschnitt ausklappen",
  "section_menu_action_manage_section": "Abschnitt verwalten",
  "section_menu_action_manage_webext": "Erweiterung verwalten",
  "section_menu_action_add_topsite": "Wichtige Seite hinzufügen",
  "section_menu_action_add_search_engine": "Suchmaschine hinzufügen",
  "section_menu_action_move_up": "Nach oben schieben",
  "section_menu_action_move_down": "Nach unten schieben",
  "section_menu_action_privacy_notice": "Datenschutzhinweis",
  "firstrun_title": "Firefox für unterwegs",
  "firstrun_content": "Nimm Lesezeichen, Chronik, Passwörter und andere Einstellungen mit auf alle deine Geräten.",
  "firstrun_learn_more_link": "Weitere Infos zum Firefox-Konto",
  "firstrun_form_header": "E-Mail-Adresse eingeben",
  "firstrun_form_sub_header": "um dich bei Firefox Sync anzumelden",
  "firstrun_email_input_placeholder": "E-Mail",
  "firstrun_invalid_input": "Gültige E-Mail-Adresse erforderlich",
  "firstrun_extra_legal_links": "Indem du fortfährst, stimmst du unseren {terms} und dem {privacy} zu.",
  "firstrun_terms_of_service": "Nutzungsbedingungen",
  "firstrun_privacy_notice": "Datenschutzhinweis",
  "firstrun_continue_to_login": "Weiter",
  "firstrun_skip_login": "Diesen Schritt überspringen",
  "context_menu_title": "Menü öffnen"
};
